diff --git a/front/js/app-init.js b/front/js/app-init.js
index 96bd2f4e..fe294043 100644
--- a/front/js/app-init.js
+++ b/front/js/app-init.js
@@ -126,7 +126,7 @@ function isAppInitialized() {
lang_shouldBeCompletedCalls = getLangCode() == 'en_us' ? 1 : 2;
- // check if each ajax call completed succesfully
+ // check if each ajax call completed successfully
for (const call_name of completedCalls_final) {
if (getCache(CACHE_KEYS.initFlag(call_name)) != "true") {
_isAppInitLog(`[isAppInitialized] waiting on ${call_name} (value: ${getCache(CACHE_KEYS.initFlag(call_name))})`);
@@ -268,7 +268,7 @@ setTimeout(() => {
// page refresh if configured
const refreshTime = getSetting("UI_REFRESH");
if (refreshTime && refreshTime !== "0" && refreshTime !== "") {
- console.log("Refreshing page becasue UI_REFRESH setting enabled.");
+ console.log("Refreshing page because UI_REFRESH setting enabled.");
newTimerRefreshData(clearCache, parseInt(refreshTime)*1000);
}
diff --git a/front/php/templates/language/en_us.json b/front/php/templates/language/en_us.json
index 69f3e195..155b331e 100755
--- a/front/php/templates/language/en_us.json
+++ b/front/php/templates/language/en_us.json
@@ -400,11 +400,11 @@
"Login_Toggle_Info_headline": "Password Information",
"Maint_PurgeLog": "Purge log",
"Maint_RestartServer": "Restart server",
- "Maint_Restart_Server_noti_text": "Are you sure you want to restart the backend server? This may casue app inconsistency. Backup your setup first.
Note: This may take a few minutes.",
+ "Maint_Restart_Server_noti_text": "Are you sure you want to restart the backend server? This may cause app inconsistency. Backup your setup first.
Note: This may take a few minutes.",
"Maintenance_InitCheck": "Init check",
"Maintenance_InitCheck_Checking": "Checking…",
"Maintenance_InitCheck_QuickSetupGuide": "Make sure you followed the quick setup guide.",
- "Maintenance_InitCheck_Success": "Application initialized succesfully!",
+ "Maintenance_InitCheck_Success": "Application initialized successfully!",
"Maintenance_ReCheck": "Retry check",
"Maintenance_Running_Version": "Installed version",
"Maintenance_Status": "Status",
diff --git a/front/js/ui_components.js b/front/js/ui_components.js
index 7ac966f1..d7cb7f71 100755
--- a/front/js/ui_components.js
+++ b/front/js/ui_components.js
@@ -590,6 +590,7 @@ function addOptionFromModalInput() {
* A MAC is considered fake if it starts with:
* - "FA:CE" (new synthetic devices)
* - "00:1A" (legacy placeholder devices)
+ * - "02:" (legacy placeholder devices)
*
* The check is case-insensitive.
*
@@ -600,8 +601,8 @@ function isFakeMac(macAddress) {
// Normalize to lowercase for consistent comparison
macAddress = macAddress.toLowerCase();
- // Check if MAC starts with FA:CE or 00:1a
- return macAddress.startsWith("fa:ce") || macAddress.startsWith("00:1a");
+ // Check if MAC starts with FA:CE or 00:1a or 02:
+ return macAddress.startsWith("fa:ce") || macAddress.startsWith("00:1a") || macAddress.startsWith("02:");
}